package org.jeecg.modules.okki.account.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.FastJsonUtil;
import org.jeecg.modules.okki.account.dto.OkkiBindSiteDto;
import org.jeecg.modules.okki.account.entity.OkkiAccount;
import org.jeecg.modules.okki.account.param.OkkiAccountResetPwdParam;
import org.jeecg.modules.okki.account.service.IOkkiAccountService;
import org.jeecg.modules.okki.siteuser.entity.OkkiSiteUser;
import org.jeecg.modules.okki.siteuser.service.IOkkiSiteUserService;
import org.jeecg.modules.system.service.ISysDictService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @Description: 小二账号
 * @Author: jeecg-boot
 * @Date: 2024-05-22
 * @Version: V1.0
 */
@Api(tags = "小二账号")
@RestController
@RequestMapping("/account/okkiAccount")
@Slf4j
public class OkkiAccountController extends JeecgController<OkkiAccount, IOkkiAccountService> {
    @Autowired
    private IOkkiAccountService okkiAccountService;

    @Autowired
    private ISysDictService sysDictService;

    @Autowired
    private IOkkiSiteUserService okkiSiteUserService;

    /**
     * 分页列表查询
     *
     * @param okkiAccount
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "小二账号-分页列表查询")
    @ApiOperation(value = "小二账号-分页列表查询", notes = "小二账号-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<OkkiAccount>> queryPageList(OkkiAccount okkiAccount,
                                                    @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                    @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                    HttpServletRequest req) {
        QueryWrapper<OkkiAccount> queryWrapper = QueryGenerator.initQueryWrapper(okkiAccount, req.getParameterMap());
        Page<OkkiAccount> page = new Page<OkkiAccount>(pageNo, pageSize);
        IPage<OkkiAccount> pageList = okkiAccountService.page(page, queryWrapper);
        List<OkkiAccount> okkiAccounts = pageList.getRecords();
        if(!okkiAccounts.isEmpty()){
            okkiAccounts.forEach(item -> {
                List<OkkiSiteUser> okkiSiteUsers = okkiSiteUserService.getSiteUserInfoByUserId(item.getUserId());
                List<Integer> siteIds = okkiSiteUsers.stream().map(OkkiSiteUser::getSiteId).collect(Collectors.toList());
                String result = siteIds.stream()
                        .map(String::valueOf)
                        .collect(Collectors.joining(","));
                item.setSiteIds(result);
            });
        }
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param okkiAccount
     * @return
     */
    @AutoLog(value = "小二账号-添加")
    @ApiOperation(value = "小二账号-添加", notes = "小二账号-添加")
    @RequiresPermissions("account:okki_account:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody OkkiAccount okkiAccount) {
//		okkiAccountService.insertAccount(okkiAccount);
        // todo 接口增加3个新参数和参数类型修改
        okkiAccountService.insertAccountV2(okkiAccount);
        return Result.OK("添加成功！");
    }

    /**
     * 编辑
     *
     * @param okkiAccount
     * @return
     */
    @AutoLog(value = "小二账号-编辑")
    @ApiOperation(value = "小二账号-编辑", notes = "小二账号-编辑")
    @RequiresPermissions("account:okki_account:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody OkkiAccount okkiAccount) {
//		okkiAccountService.updateAccount(okkiAccount);
        okkiAccountService.resetRoleV2(okkiAccount);
        return Result.OK("编辑成功!");
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "小二账号-通过id删除")
    @ApiOperation(value = "小二账号-通过id删除", notes = "小二账号-通过id删除")
    @RequiresPermissions("account:okki_account:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        okkiAccountService.removeById(id);
        return Result.OK("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "小二账号-批量删除")
    @ApiOperation(value = "小二账号-批量删除", notes = "小二账号-批量删除")
    @RequiresPermissions("account:okki_account:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.okkiAccountService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK("批量删除成功!");
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "小二账号-通过id查询")
    @ApiOperation(value = "小二账号-通过id查询", notes = "小二账号-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<OkkiAccount> queryById(@RequestParam(name = "id", required = true) String id) {
        OkkiAccount okkiAccount = okkiAccountService.getById(id);
        if (okkiAccount == null) {
            return Result.error("未找到对应数据");
        }
        return Result.OK(okkiAccount);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param okkiAccount
     */
    @RequiresPermissions("account:okki_account:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OkkiAccount okkiAccount) {
        return super.exportXls(request, okkiAccount, OkkiAccount.class, "小二账号");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("account:okki_account:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OkkiAccount.class);
    }

    /**
     * 授权
     *
     * @param okkiAccount
     * @return
     */
    @AutoLog(value = "小二账号-授权")
    @ApiOperation(value = "小二账号-授权", notes = "小二账号-授权")
    @RequiresPermissions("account:okki_account:edit")
    @RequestMapping(value = "/resetRole", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> resetRole(@RequestBody OkkiAccount okkiAccount) {
//		 okkiAccountService.resetRole(okkiAccount);
        okkiAccountService.resetRoleV2(okkiAccount);
        return Result.OK("编辑成功!");
    }

    /**
     * 绑定站点
     *
     * @param okkiAccount
     * @return
     */
    @AutoLog(value = "小二账号-绑定站点")
    @ApiOperation(value = "小二账号-绑定站点", notes = "小二账号-绑定站点")
    @RequiresPermissions("account:okki_account:edit")
//    @RequestMapping(value = "/bindSite", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> bindSite(@RequestBody OkkiAccount okkiAccount) {
//		 okkiAccountService.bindSites(okkiAccount);
        // todo 接口升级更换
//        okkiAccountService.bindSitesV2(okkiAccount);
        return Result.OK("编辑成功!");
    }

    /**
     * 绑定站点
     *
     * @param okkiBindSiteDto
     * @return
     */
    @AutoLog(value = "小二账号-绑定站点V2")
    @ApiOperation(value = "小二账号-绑定站点V2", notes = "小二账号-绑定站点V2")
    @RequiresPermissions("account:okki_account:edit")
    @RequestMapping(value = "/bindSiteV2", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> bindSitesV2(@RequestBody OkkiBindSiteDto okkiBindSiteDto) {
        log.info("okkiBindSiteDto:{}", FastJsonUtil.toJSONString(okkiBindSiteDto));
        okkiAccountService.bindSitesV2(okkiBindSiteDto);
        return Result.OK("操作成功!");
    }


    /**
     * 重置密码
     *
     * @param okkiAccountResetPwdParam
     * @return
     */
    @AutoLog(value = "小二账号-绑定站点")
    @ApiOperation(value = "小二账号-重置密码", notes = "小二账号-重置密码")
    @RequiresPermissions("account:okki_account:edit")
    @RequestMapping(value = "/resetPwd", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> resetPwd(@RequestBody OkkiAccountResetPwdParam okkiAccountResetPwdParam) {
        okkiAccountService.resetPwd(okkiAccountResetPwdParam);
        return Result.OK("编辑成功!");
    }

    /**
     * 获取小二账号
     *
     * @param okkiAccount
     * @param req
     * @return
     */
    @ApiOperation(value = "小二账号-获取小二账号", notes = "小二账号-获取小二账号")
    @GetMapping(value = "/user")
    public Result<?> getOkkiUser(OkkiAccount okkiAccount,
                                 HttpServletRequest req) {
//        List<DictModel> dictModels = sysDictService.getDictItems("user_role");
//            log.info("dictModels:{}",FastJsonUtil.toJSONString(dictModels));
//        Map<Integer, Object> userRoleMap = new HashMap<>();
//        dictModels.forEach(c -> {
//            QueryWrapper<OkkiAccount> queryWrapper = new QueryWrapper<>();
//            queryWrapper.eq("user_role", Integer.valueOf(c.getValue()));
//            queryWrapper.eq("status", 0).select("name,user_id,user_role");
//            List<OkkiAccount> accounts = okkiAccountService.list(queryWrapper);
//
//            List<Map<String, Object>> accountsMap = new ArrayList<>();
//            accounts.forEach(a -> {
//                Map<String, Object> accountMap = new HashMap<>();
//                accountMap.put("id", a.getId());
//                accountMap.put("name", a.getName());
//                accountMap.put("userId", a.getUserId());
//                accountMap.put("userRole", a.getUserRole());
//                accountsMap.add(accountMap);
//            });
//            userRoleMap.put(Integer.valueOf(c.getValue()), accountsMap);
//        });
//        log.info("userRoleMap:{}", FastJsonUtil.toJSONString(userRoleMap));
//        return Result.OK(userRoleMap);

//        OkkiSite okkiSite = new OkkiSite();
//        okkiSite.setSiteId(String.valueOf(2314));
//        okkiAccountService.getSiteBindInfo(okkiSite);

        QueryWrapper<OkkiAccount> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("user_role", okkiAccount.getUserRole());
        queryWrapper.eq("status", 0).select("name,user_id,user_role");
        List<OkkiAccount> accounts = okkiAccountService.list(queryWrapper);

        List<Map<String, Object>> accountsMap = new ArrayList<>();
        accounts.forEach(a -> {
            Map<String, Object> accountMap = new HashMap<>();
            accountMap.put("id", a.getId());
            accountMap.put("name", a.getName());
            accountMap.put("userId", a.getUserId());
            accountMap.put("userRole", a.getUserRole());
            accountsMap.add(accountMap);
        });
        return Result.OK(accountsMap);
    }
}
