package org.jeecg.modules.okki.google.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.okki.google.entity.OkkiGoogleAdsAccount;
import org.jeecg.modules.okki.google.service.IOkkiGoogleAdsAccountService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: Google Ads账号管理
 * @Author: jeecg-boot
 * @Date:   2024-05-17
 * @Version: V1.0
 */
@Api(tags="Google Ads账号管理")
@RestController
@RequestMapping("/google/okkiGoogleAdsAccount")
@Slf4j
public class OkkiGoogleAdsAccountController extends JeecgController<OkkiGoogleAdsAccount, IOkkiGoogleAdsAccountService> {
	@Autowired
	private IOkkiGoogleAdsAccountService okkiGoogleAdsAccountService;
	
	/**
	 * 分页列表查询
	 *
	 * @param okkiGoogleAdsAccount
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "Google Ads账号管理-分页列表查询")
	@ApiOperation(value="Google Ads账号管理-分页列表查询", notes="Google Ads账号管理-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<OkkiGoogleAdsAccount>> queryPageList(OkkiGoogleAdsAccount okkiGoogleAdsAccount,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<OkkiGoogleAdsAccount> queryWrapper = QueryGenerator.initQueryWrapper(okkiGoogleAdsAccount, req.getParameterMap());
		Page<OkkiGoogleAdsAccount> page = new Page<OkkiGoogleAdsAccount>(pageNo, pageSize);
		IPage<OkkiGoogleAdsAccount> pageList = okkiGoogleAdsAccountService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param okkiGoogleAdsAccount
	 * @return
	 */
	@AutoLog(value = "Google Ads账号管理-添加")
	@ApiOperation(value="Google Ads账号管理-添加", notes="Google Ads账号管理-添加")
	@RequiresPermissions("google:okki_google_ads_account:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody OkkiGoogleAdsAccount okkiGoogleAdsAccount) {
		okkiGoogleAdsAccountService.save(okkiGoogleAdsAccount);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param okkiGoogleAdsAccount
	 * @return
	 */
	@AutoLog(value = "Google Ads账号管理-编辑")
	@ApiOperation(value="Google Ads账号管理-编辑", notes="Google Ads账号管理-编辑")
	@RequiresPermissions("google:okki_google_ads_account:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody OkkiGoogleAdsAccount okkiGoogleAdsAccount) {
		okkiGoogleAdsAccountService.updateById(okkiGoogleAdsAccount);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "Google Ads账号管理-通过id删除")
	@ApiOperation(value="Google Ads账号管理-通过id删除", notes="Google Ads账号管理-通过id删除")
	@RequiresPermissions("google:okki_google_ads_account:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		okkiGoogleAdsAccountService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "Google Ads账号管理-批量删除")
	@ApiOperation(value="Google Ads账号管理-批量删除", notes="Google Ads账号管理-批量删除")
	@RequiresPermissions("google:okki_google_ads_account:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.okkiGoogleAdsAccountService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "Google Ads账号管理-通过id查询")
	@ApiOperation(value="Google Ads账号管理-通过id查询", notes="Google Ads账号管理-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<OkkiGoogleAdsAccount> queryById(@RequestParam(name="id",required=true) String id) {
		OkkiGoogleAdsAccount okkiGoogleAdsAccount = okkiGoogleAdsAccountService.getById(id);
		if(okkiGoogleAdsAccount==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(okkiGoogleAdsAccount);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param okkiGoogleAdsAccount
    */
    @RequiresPermissions("google:okki_google_ads_account:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OkkiGoogleAdsAccount okkiGoogleAdsAccount) {
        return super.exportXls(request, okkiGoogleAdsAccount, OkkiGoogleAdsAccount.class, "Google Ads账号管理");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("google:okki_google_ads_account:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OkkiGoogleAdsAccount.class);
    }

}
