package org.jeecg.modules.okki.site.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.jeecg.common.aspect.annotation.Dict;
import org.jeecgframework.poi.excel.annotation.Excel;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @Description: 站点
 * @Author: jeecg-boot
 * @Date:   2024-05-23
 * @Version: V1.0
 */
@Data
@TableName("okki_site")
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value="okki_site对象", description="站点")
public class OkkiSite implements Serializable {
    private static final long serialVersionUID = 1L;

	/**主键*/
	@TableId(type = IdType.ASSIGN_ID)
    @ApiModelProperty(value = "主键")
    private String id;
	/**创建人*/
    @ApiModelProperty(value = "创建人")
    private String createBy;
	/**创建日期*/
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty(value = "创建日期")
    private Date createTime;
	/**更新人*/
    @ApiModelProperty(value = "更新人")
    private String updateBy;
	/**更新日期*/
	@JsonFormat(timezone = "GMT+8",pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty(value = "更新日期")
    private Date updateTime;
	/**站点id*/
	@Excel(name = "站点id", width = 15)
    @ApiModelProperty(value = "站点id")
    private String siteId;
	/**公司名称*/
	@Excel(name = "公司名称", width = 15)
    @ApiModelProperty(value = "公司名称")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String companyName;
	/**初始化的域名*/
	@Excel(name = "初始化的域名", width = 15)
    @ApiModelProperty(value = "初始化的域名")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String domain;
	/**联系方式*/
	@Excel(name = "联系方式", width = 15)
    @ApiModelProperty(value = "联系方式")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String tel;
	/**联系人*/
	@Excel(name = "联系人", width = 15)
    @ApiModelProperty(value = "联系人")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String contact;
	/**邮箱*/
	@Excel(name = "邮箱", width = 15)
    @ApiModelProperty(value = "邮箱")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String email;
	/**公司名英⽂简称*/
	@Excel(name = "公司名英⽂简称", width = 15)
    @ApiModelProperty(value = "公司名英⽂简称")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String enname;
	/**套餐名*/
	@Excel(name = "套餐名", width = 15)
    @ApiModelProperty(value = "套餐名")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String tcName;
	/**套餐周期，单位⽉*/
	@Excel(name = "套餐周期，单位⽉", width = 15)
    @ApiModelProperty(value = "套餐周期，单位⽉")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private Integer tcPeriod;
	/**站点选择的⼩语种语⾔*/
	@Excel(name = "站点选择的⼩语种语⾔", width = 15)
    @ApiModelProperty(value = "站点选择的⼩语种语⾔")
    private String tcLanguage;
	/**备注*/
	@Excel(name = "备注", width = 15)
    @ApiModelProperty(value = "备注")
    @TableField(updateStrategy = FieldStrategy.NOT_EMPTY)
    private String remark;
    /**状态*/
    @Excel(name = "状态", width = 15, dicCode = "site_status")
    @Dict(dicCode = "site_status")
    @ApiModelProperty(value = "状态")
    private Integer status;
    /**所属部门*/
    @Dict(dictTable = "sys_depart", dicText = "depart_name", dicCode = "org_code")
    @ApiModelProperty(value = "所属部门")
    private java.lang.String sysOrgCode;
    /**所属人员*/
    @Excel(name = "所属人员", width = 15, dictTable = "sys_user", dicText = "realname", dicCode = "username")
    @Dict(dictTable = "sys_user", dicText = "realname", dicCode = "username")
    @ApiModelProperty(value = "所属人员")
    private java.lang.String sysUserCode;

    @TableField(exist = false)
    private String serviceManageUserStr;

    @TableField(exist = false)
    private List<Integer> serviceManageUser;

    @TableField(exist = false)
    private String dataUserStr;

    @TableField(exist = false)
    private List<Integer> dataUser;

    @TableField(exist = false)
    private String kefuUserStr;

    @TableField(exist = false)
    private List<Integer> kefuUser;

    @TableField(exist = false)
    private String seoUserStr;

    @TableField(exist = false)
    private List<Integer> seoUser;

    @TableField(exist = false)
    private String semManageUserStr;

    @TableField(exist = false)
    private List<Integer> semManageUser;

    @TableField(exist = false)
    private String semUserStr;

    @TableField(exist = false)
    private List<Integer> semUser;

    @TableField(exist = false)
    private String uiUserStr;

    @TableField(exist = false)
    private List<Integer> uiUser;

    @TableField(exist = false)
    private String websiteUserStr;

    @TableField(exist = false)
    private List<Integer> websiteUser;

    @TableField(exist = false)
    private String socialUserStr;

    @TableField(exist = false)
    private List<Integer> socialUser;

    @TableField(exist = false)
    private String rdUserStr;

    @TableField(exist = false)
    private List<Integer> rdUser;

    /**
     * 删除状态（0，正常，1已删除）
     */
    @TableLogic
    private java.lang.Integer delFlag;
}
