package org.jeecg.modules.okki.siteuser.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.okki.siteuser.entity.OkkiSiteUser;
import org.jeecg.modules.okki.siteuser.service.IOkkiSiteUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: okki_site_user
 * @Author: jeecg-boot
 * @Date:   2024-11-15
 * @Version: V1.0
 */
@Api(tags="okki_site_user")
@RestController
@RequestMapping("/okki/okkiSiteUser")
@Slf4j
public class OkkiSiteUserController extends JeecgController<OkkiSiteUser, IOkkiSiteUserService> {
	@Autowired
	private IOkkiSiteUserService okkiSiteUserService;
	
	/**
	 * 分页列表查询
	 *
	 * @param okkiSiteUser
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "okki_site_user-分页列表查询")
	@ApiOperation(value="okki_site_user-分页列表查询", notes="okki_site_user-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<OkkiSiteUser>> queryPageList(OkkiSiteUser okkiSiteUser,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<OkkiSiteUser> queryWrapper = QueryGenerator.initQueryWrapper(okkiSiteUser, req.getParameterMap());
		Page<OkkiSiteUser> page = new Page<OkkiSiteUser>(pageNo, pageSize);
		IPage<OkkiSiteUser> pageList = okkiSiteUserService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param okkiSiteUser
	 * @return
	 */
	@AutoLog(value = "okki_site_user-添加")
	@ApiOperation(value="okki_site_user-添加", notes="okki_site_user-添加")
	@RequiresPermissions("okki:okki_site_user:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody OkkiSiteUser okkiSiteUser) {
		okkiSiteUserService.save(okkiSiteUser);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param okkiSiteUser
	 * @return
	 */
	@AutoLog(value = "okki_site_user-编辑")
	@ApiOperation(value="okki_site_user-编辑", notes="okki_site_user-编辑")
	@RequiresPermissions("okki:okki_site_user:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody OkkiSiteUser okkiSiteUser) {
		okkiSiteUserService.updateById(okkiSiteUser);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "okki_site_user-通过id删除")
	@ApiOperation(value="okki_site_user-通过id删除", notes="okki_site_user-通过id删除")
	@RequiresPermissions("okki:okki_site_user:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		okkiSiteUserService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "okki_site_user-批量删除")
	@ApiOperation(value="okki_site_user-批量删除", notes="okki_site_user-批量删除")
	@RequiresPermissions("okki:okki_site_user:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.okkiSiteUserService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "okki_site_user-通过id查询")
	@ApiOperation(value="okki_site_user-通过id查询", notes="okki_site_user-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<OkkiSiteUser> queryById(@RequestParam(name="id",required=true) String id) {
		OkkiSiteUser okkiSiteUser = okkiSiteUserService.getById(id);
		if(okkiSiteUser==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(okkiSiteUser);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param okkiSiteUser
    */
    @RequiresPermissions("okki:okki_site_user:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OkkiSiteUser okkiSiteUser) {
        return super.exportXls(request, okkiSiteUser, OkkiSiteUser.class, "okki_site_user");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("okki:okki_site_user:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OkkiSiteUser.class);
    }

}
