package org.jeecg.modules.okki.wechatgroup.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.okki.wechatgroup.entity.OkkiShopWechatGroupMsg;
import org.jeecg.modules.okki.wechatgroup.service.IOkkiShopWechatGroupMsgService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: okki_shop_wechat_group_msg
 * @Author: jeecg-boot
 * @Date:   2024-09-09
 * @Version: V1.0
 */
@Api(tags="okki_shop_wechat_group_msg")
@RestController
@RequestMapping("/okki/okkiShopWechatGroupMsg")
@Slf4j
public class OkkiShopWechatGroupMsgController extends JeecgController<OkkiShopWechatGroupMsg, IOkkiShopWechatGroupMsgService> {
	@Autowired
	private IOkkiShopWechatGroupMsgService okkiShopWechatGroupMsgService;
	
	/**
	 * 分页列表查询
	 *
	 * @param okkiShopWechatGroupMsg
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "okki_shop_wechat_group_msg-分页列表查询")
	@ApiOperation(value="okki_shop_wechat_group_msg-分页列表查询", notes="okki_shop_wechat_group_msg-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<OkkiShopWechatGroupMsg>> queryPageList(OkkiShopWechatGroupMsg okkiShopWechatGroupMsg,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<OkkiShopWechatGroupMsg> queryWrapper = QueryGenerator.initQueryWrapper(okkiShopWechatGroupMsg, req.getParameterMap());
		Page<OkkiShopWechatGroupMsg> page = new Page<OkkiShopWechatGroupMsg>(pageNo, pageSize);
		IPage<OkkiShopWechatGroupMsg> pageList = okkiShopWechatGroupMsgService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param okkiShopWechatGroupMsg
	 * @return
	 */
	@AutoLog(value = "okki_shop_wechat_group_msg-添加")
	@ApiOperation(value="okki_shop_wechat_group_msg-添加", notes="okki_shop_wechat_group_msg-添加")
	@RequiresPermissions("okki:okki_shop_wechat_group_msg:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody OkkiShopWechatGroupMsg okkiShopWechatGroupMsg) {
		okkiShopWechatGroupMsgService.save(okkiShopWechatGroupMsg);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param okkiShopWechatGroupMsg
	 * @return
	 */
	@AutoLog(value = "okki_shop_wechat_group_msg-编辑")
	@ApiOperation(value="okki_shop_wechat_group_msg-编辑", notes="okki_shop_wechat_group_msg-编辑")
	@RequiresPermissions("okki:okki_shop_wechat_group_msg:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody OkkiShopWechatGroupMsg okkiShopWechatGroupMsg) {
		okkiShopWechatGroupMsgService.updateById(okkiShopWechatGroupMsg);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "okki_shop_wechat_group_msg-通过id删除")
	@ApiOperation(value="okki_shop_wechat_group_msg-通过id删除", notes="okki_shop_wechat_group_msg-通过id删除")
	@RequiresPermissions("okki:okki_shop_wechat_group_msg:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		okkiShopWechatGroupMsgService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "okki_shop_wechat_group_msg-批量删除")
	@ApiOperation(value="okki_shop_wechat_group_msg-批量删除", notes="okki_shop_wechat_group_msg-批量删除")
	@RequiresPermissions("okki:okki_shop_wechat_group_msg:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.okkiShopWechatGroupMsgService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "okki_shop_wechat_group_msg-通过id查询")
	@ApiOperation(value="okki_shop_wechat_group_msg-通过id查询", notes="okki_shop_wechat_group_msg-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<OkkiShopWechatGroupMsg> queryById(@RequestParam(name="id",required=true) String id) {
		OkkiShopWechatGroupMsg okkiShopWechatGroupMsg = okkiShopWechatGroupMsgService.getById(id);
		if(okkiShopWechatGroupMsg==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(okkiShopWechatGroupMsg);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param okkiShopWechatGroupMsg
    */
    @RequiresPermissions("okki:okki_shop_wechat_group_msg:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, OkkiShopWechatGroupMsg okkiShopWechatGroupMsg) {
        return super.exportXls(request, okkiShopWechatGroupMsg, OkkiShopWechatGroupMsg.class, "okki_shop_wechat_group_msg");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("okki:okki_shop_wechat_group_msg:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, OkkiShopWechatGroupMsg.class);
    }

}
