import {defHttp} from '/@/utils/http/axios';
import { useMessage } from "/@/hooks/web/useMessage";

const { createConfirm } = useMessage();

enum Api {
  list = '/site/okkiSite/list',
  save='/site/okkiSite/add',
  edit='/site/okkiSite/edit',
  updateStatus = '/site/okkiSite/status',
  deleteOne = '/site/okkiSite/delete',
  deleteBatch = '/site/okkiSite/deleteBatch',
  importExcel = '/site/okkiSite/importExcel',
  exportXls = '/site/okkiSite/exportXls',
  getOkkiUser = '/account/okkiAccount/user',
  bindSiteV2 = '/account/okkiAccount/bindSiteV2',
  siteBindInfo = '/account/okkiAccount/siteBindInfo',
}
/**
 * 导出api
 * @param params
 */
export const getExportUrl = Api.exportXls;
/**
 * 导入api
 */
export const getImportUrl = Api.importExcel;
/**
 * 列表接口
 * @param params
 */
export const list = (params) =>
  defHttp.get({url: Api.list, params});

/**
 * 修改状态
 */
export const updateStatus = (params,handleSuccess) => {
  return defHttp.post({url: Api.updateStatus, params}, {joinParamsToUrl: true}).then(() => {
    handleSuccess();
  });
}

/**
 * 删除单个
 */
export const deleteOne = (params,handleSuccess) => {
  return defHttp.delete({url: Api.deleteOne, params}, {joinParamsToUrl: true}).then(() => {
    handleSuccess();
  });
}
/**
 * 批量删除
 * @param params
 */
export const batchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认删除',
    content: '是否删除选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.deleteBatch, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}
/**
 * 保存或者更新
 * @param params
 */
export const saveOrUpdate = (params, isUpdate) => {
  let url = isUpdate ? Api.edit : Api.save;
  return defHttp.post({url: url, params});
}

/**
 * 保存站点小二分配
 * @param params
 */
export const saveXiaoErBind = (params) => {
  console.log("saveXiaoErBind --- params:{}",params)
  return defHttp.post({url: Api.bindSiteV2, params});
}

/**
 * 获取小二账号列表
 * @param params
 */
export const getOkkiAccounts = (params) => {
  return defHttp.get({url: Api.getOkkiUser, params});
}

/**
 * 获取小二账号列表
 * @param params
 */
export const getSiteBindInfo = (params) => {
  return defHttp.get({url: Api.siteBindInfo, params});
}
